| Title: | An RKWard plugin package for Quality Control Charts and Capability Analysis using the 'qcc' library. |
|---|---|
| Description: | An RKWard plugin package for Quality Control Charts and Capability Analysis using the 'qcc' library. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.1 |
| Built: | 2026-06-04 10:05:24 UTC |
| Source: | https://github.com/AlfCano/rk.qcc |